@@ -65,10 +65,13 @@ def Regress(mirror_rp):
 	assert mirror_rp.conn is inc_rpath.conn is Globals.local_connection
 	set_regress_time()
 	set_restore_times()
+	former_current_mirror_rp = remove_rbdir_increments()
 	ITR = rorpiter.IterTreeReducer(RegressITRB, [])
 	for rf in iterate_meta_rfs(mirror_rp, inc_rpath): ITR(rf.index, rf)
 	ITR.Finish()
-	remove_rbdir_increments()
+	if former_current_mirror_rp:
+		C.sync() # Sync first, since we are marking dest dir as good now
+		former_current_mirror_rp.delete()
 
 def set_regress_time():
 	"""Set global regress_time to previous sucessful backup
@@ -98,43 +101,44 @@ def set_restore_times():
 	restore._rest_time = regress_time
 
 def remove_rbdir_increments():
-	"""Delete the increments in the rdiff-backup-data directory"""
-	old_current_mirror = None
+	"""Delete the increments in the rdiff-backup-data directory
+
+	Returns the former current mirror rp so we can delete it later.
+	All of the other rp's should be deleted before the actual regress,
+	to clear up disk space the rest of the procedure may need.
+
+	"""
+	former_current_mirror = None
 	for filename in Globals.rbdir.listdir():
 		rp = Globals.rbdir.append(filename)
 		if rp.isincfile() and rp.getinctime() == unsuccessful_backup_time:
-			if rp.getincbase_str() == "current_mirror": old_current_mirror = rp
+			if rp.getincbase_str() == "current_mirror":
+				former_current_mirror = rp
 			else:
 				log.Log("Removing rdiff-backup-data increment " + rp.path, 5)
 				rp.delete()
-	if old_current_mirror:
-		C.sync() # Sync first, since we are marking dest dir as good now
-		old_current_mirror.delete()
+	return former_current_mirror
 
 def iterate_raw_rfs(mirror_rp, inc_rp):
 	"""Iterate all RegressFile objects in mirror/inc directory
 
-	Also changes permissions of unreadable files to allow access and
-	then changes them back later.
+	Also changes permissions of unreadable files.  We don't have to
+	change them back later because regress will do that for us.
 
 	"""
 	root_rf = RegressFile(mirror_rp, inc_rp, restore.get_inclist(inc_rp))
 	def helper(rf):
 		mirror_rp = rf.mirror_rp
-		if (Globals.process_uid != 0 and
-			((mirror_rp.isreg() and not mirror_rp.readable()) or
-			 (mirror_rp.isdir() and not mirror_rp.hasfullperms()))):
-			unreadable, old_perms = 1, mirror_rp.getperms()
-			if mirror_rp.isreg(): mirror_rp.chmod(0400 | old_perms)
-			else: mirror_rp.chmod(0700 | old_perms)
-		else: unreadable = 0
+		if Globals.process_uid != 0:
+			if mirror_rp.isreg() and not mirror_rp.readable():
+				mirror_rp.chmod(0400 | mirror_rp.getperms())
+			elif mirror_rp.isdir() and not mirror_rp.hasfullperms():
+				mirror_rp.chmod(0700 | mirror_rp.getperms())
 		yield rf
-		if unreadable and mirror_rp.isreg(): mirror_rp.chmod(old_perms)
 		if rf.mirror_rp.isdir() or rf.inc_rp.isdir():
 			for sub_rf in rf.yield_sub_rfs():
 				for sub_sub_rf in helper(sub_rf):
 					yield sub_sub_rf
-		if unreadable and mirror_rp.isdir(): mirror_rp.chmod(old_perms)
 	return helper(root_rf)
 
 def yield_metadata():
@@ -249,14 +253,14 @@ class RegressITRB(rorpiter.ITRBranch):
 		if rf.mirror_rp.isreg():
 			tf = TempFile.new(rf.mirror_rp)
 			tf.write_from_fileobj(rf.get_restore_fp())
-			rpath.copy_attribs(rf.metadata_rorp, tf)
 			tf.fsync_with_dir() # make sure tf fully written before move
+			rpath.copy_attribs(rf.metadata_rorp, tf)
 			rpath.rename(tf, rf.mirror_rp) # move is atomic
 		else:
 			if rf.mirror_rp.lstat(): rf.mirror_rp.delete()
 			rf.mirror_rp.write_from_fileobj(rf.get_restore_fp())
 			rpath.copy_attribs(rf.metadata_rorp, rf.mirror_rp)
-		rf.mirror_rp.fsync_with_dir() # require move before inc delete
+		rf.mirror_rp.get_parent_rp().fsync() # require move before inc delete
 
 	def start_process(self, index, rf):
 		"""Start processing directory"""
